"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.fixedZero = fixedZero;
exports.getTimeDistance = getTimeDistance;
exports.getPlainNode = getPlainNode;
exports.digitUppercase = digitUppercase;
exports.getRoutes = getRoutes;
exports.getPageQuery = getPageQuery;
exports.getQueryPath = getQueryPath;
exports.isUrl = isUrl;
exports.clearAllSpace = clearAllSpace;
exports.checkDate = checkDate;
exports.intlFormat = exports.downloadFile = exports.getOptionDataText = exports.getOptionDataValue = void 0;

var _moment = _interopRequireDefault(require("moment"));

var _qs = require("qs");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

function fixedZero(val) {
  return val * 1 < 10 ? "0".concat(val) : val;
}

function getTimeDistance(type) {
  var now = new Date();
  var oneDay = 1000 * 60 * 60 * 24;

  if (type === 'today') {
    now.setHours(0);
    now.setMinutes(0);
    now.setSeconds(0);
    return [(0, _moment["default"])(now), (0, _moment["default"])(now.getTime() + (oneDay - 1000))];
  }

  if (type === 'week') {
    var day = now.getDay();
    now.setHours(0);
    now.setMinutes(0);
    now.setSeconds(0);

    if (day === 0) {
      day = 6;
    } else {
      day -= 1;
    }

    var beginTime = now.getTime() - day * oneDay;
    return [(0, _moment["default"])(beginTime), (0, _moment["default"])(beginTime + (7 * oneDay - 1000))];
  }

  if (type === 'month') {
    var year = now.getFullYear();
    var month = now.getMonth();
    var nextDate = (0, _moment["default"])(now).add(1, 'months');
    var nextYear = nextDate.year();
    var nextMonth = nextDate.month();
    return [(0, _moment["default"])("".concat(year, "-").concat(fixedZero(month + 1), "-01 00:00:00")), (0, _moment["default"])((0, _moment["default"])("".concat(nextYear, "-").concat(fixedZero(nextMonth + 1), "-01 00:00:00")).valueOf() - 1000)];
  }

  if (type === 'year') {
    var _year = now.getFullYear();

    return [(0, _moment["default"])("".concat(_year, "-01-01 00:00:00")), (0, _moment["default"])("".concat(_year, "-12-31 23:59:59"))];
  }
}

function getPlainNode(nodeList) {
  var parentPath = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
  var arr = [];
  nodeList.forEach(function (node) {
    var item = node;
    item.path = "".concat(parentPath, "/").concat(item.path || '').replace(/\/+/g, '/');
    item.exact = true;

    if (item.children && !item.component) {
      arr.push.apply(arr, _toConsumableArray(getPlainNode(item.children, item.path)));
    } else {
      if (item.children && item.component) {
        item.exact = false;
      }

      arr.push(item);
    }
  });
  return arr;
}

function accMul(arg1, arg2) {
  var m = 0;
  var s1 = arg1.toString();
  var s2 = arg2.toString();
  m += s1.split('.').length > 1 ? s1.split('.')[1].length : 0;
  m += s2.split('.').length > 1 ? s2.split('.')[1].length : 0;
  return Number(s1.replace('.', '')) * Number(s2.replace('.', '')) / Math.pow(10, m);
}

function digitUppercase(n) {
  var fraction = ['角', '分'];
  var digit = ['零', '壹', '贰', '叁', '肆', '伍', '陆', '柒', '捌', '玖'];
  var unit = [['元', '万', '亿'], ['', '拾', '佰', '仟', '万']];
  var num = Math.abs(n);
  var s = '';
  fraction.forEach(function (item, index) {
    s += (digit[Math.floor(accMul(num, 10 * Math.pow(10, index))) % 10] + item).replace(/零./, '');
  });
  s = s || '整';
  num = Math.floor(num);

  for (var i = 0; i < unit[0].length && num > 0; i += 1) {
    var p = '';

    for (var j = 0; j < unit[1].length && num > 0; j += 1) {
      p = digit[num % 10] + unit[1][j] + p;
      num = Math.floor(num / 10);
    }

    s = p.replace(/(零.)*零$/, '').replace(/^$/, '零') + unit[0][i] + s;
  }

  return s.replace(/(零.)*零元/, '元').replace(/(零.)+/g, '零').replace(/^整$/, '零元整');
}

function getRelation(str1, str2) {
  if (str1 === str2) {
    console.warn('Two path are equal!'); // eslint-disable-line
  }

  var arr1 = str1.split('/');
  var arr2 = str2.split('/');

  if (arr2.every(function (item, index) {
    return item === arr1[index];
  })) {
    return 1;
  }

  if (arr1.every(function (item, index) {
    return item === arr2[index];
  })) {
    return 2;
  }

  return 3;
}
/* function getRenderArr(routes) {
  let renderArr = [];
  renderArr.push(routes[0]);
  for (let i = 1; i < routes.length; i += 1) {
    // 去重
    renderArr = renderArr.filter(item => getRelation(item, routes[i]) !== 1);
    // 是否包含
    const isAdd = renderArr.every(item => getRelation(item, routes[i]) === 3);
    if (isAdd) {
      renderArr.push(routes[i]);
    }
  }
  return renderArr;
} */

/**
 * Get router routing configuration
 * { path:{name,...param}}=>Array<{name,path ...param}>
 * @param {string} path
 * @param {routerData} routerData
 */


function getRoutes(path, routerData) {
  var routes = Object.keys(routerData).filter(function (routePath) {
    return routePath.indexOf(path) === 0 && routePath !== path;
  }); // Replace path to '' eg. path='user' /user/name => name

  routes = routes.map(function (item) {
    return item.replace(path, '');
  }); // Get the route to be rendered to remove the deep rendering
  //  const renderArr = getRenderArr(routes);
  // Conversion and stitching parameters

  var renderRoutes = routes.map(function (item) {
    var exact = !routes.some(function (route) {
      return route !== item && getRelation(route, item) === 1;
    });
    return _extends({
      exact: exact
    }, routerData["".concat(path).concat(item)], {
      key: "".concat(path).concat(item),
      path: "".concat(path).concat(item)
    });
  });
  return renderRoutes;
}

function getPageQuery() {
  return (0, _qs.parse)(window.location.href.split('?')[1]);
}

function getQueryPath() {
  var path = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  var query = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var search = (0, _qs.stringify)(query);

  if (search.length) {
    return "".concat(path, "?").concat(search);
  }

  return path;
}
/* eslint no-useless-escape:0 */


var reg = /(((^https?:(?:\/\/)?)(?:[-;:&=\+\$,\w]+@)?[A-Za-z0-9.-]+(?::\d+)?|(?:www.|[-;:&=\+\$,\w]+@)[A-Za-z0-9.-]+)((?:\/[\+~%\/.\w-_]*)?\??(?:[-\+=&;%@.\w_]*)#?(?:[\w]*))?)$/;

function isUrl(path) {
  return reg.test(path);
} // Auth Carson


var getOptionDataValue = function getOptionDataValue() {
  var list = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  var key = arguments.length > 1 ? arguments[1] : undefined;
  var text = null;
  list.some(function (data) {
    if (!data || data.key !== key) {
      return false;
    } // eslint-disable-next-line prefer-destructuring


    text = data.text;
    return true;
  });
  return text || key; // 找不到对应值，显示key
}; // Auth Carson


exports.getOptionDataValue = getOptionDataValue;

var getOptionDataText = function getOptionDataText() {
  var list = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  var key = arguments.length > 1 ? arguments[1] : undefined;
  var text = null;
  list.some(function (data) {
    if (!data || data.key !== key) {
      return false;
    }

    text = data.value;
    return true;
  });
  return text || key; // 找不到对应值，显示key
};

exports.getOptionDataText = getOptionDataText;

var downloadFile = function downloadFile(url) {
  if (document.getElementById('download-iframe') != null) {
    // @ts-ignore
    document.getElementById('download-iframe').remove();
  }

  var iframe = document.createElement('iframe');
  iframe.id = 'download-iframe';
  iframe.style.display = 'none';
  iframe.style.visibility = 'hidden';
  iframe.style.height = '0px';
  iframe.src = url;
  document.body.appendChild(iframe); // eslint-disable-next-line no-undef

  return new Promise(function (resolve, reject) {
    setTimeout(function () {
      // @ts-ignore
      var text = document.getElementById('download-iframe') // @ts-ignore
      .contentWindow.document.getElementsByTagName('body')[0].innerHTML;

      if (text) {
        resolve(text);
      } else {
        // eslint-disable-next-line prefer-promise-reject-errors
        reject(false);
      }
    }, 500);
  });
};

exports.downloadFile = downloadFile;

function clearAllSpace(e) {
  if (/\s/.test(String(e.target.value))) {
    e.target.value = "".concat(e.target.value).replace(/\s/g, '');
  }
}

function checkDate(date, targetDate, type) {
  var dataStr = date.format('YYYY-MM-DD');
  var hourStr = date.hour();

  switch (type) {
    case 'hour':
      {
        if (dataStr > targetDate.format('YYYY-MM-DD')) {
          return 0;
        }

        return targetDate.hour();
      }

    case 'minute':
      {
        if (dataStr > targetDate.format('YYYY-MM-DD') || hourStr > targetDate.hour()) {
          return 0;
        }

        return targetDate.minute();
      }

    default:
      return null;
  }
} // 2018-01-02 19:22:04 日期控制
// 国际化转化


var intlFormat = function intlFormat(id, defaultMessage, data) {
  if (!id) return defaultMessage;

  if (window && window.intlFormat) {
    return window.intlFormat(id, defaultMessage, data);
  }

  var newData = data || {};

  if (data && Object.keys(newData).length > 0) {
    Object.keys(newData).map(function (key) {
      defaultMessage = defaultMessage.replace("{".concat(key, "}"), newData[key]);
    });
  }

  return defaultMessage;
};

exports.intlFormat = intlFormat;