"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _request = _interopRequireDefault(require("../../_util/request"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function Dictionary() {
  // @ts-ignore
  if (Dictionary.unique !== undefined) {
    // @ts-ignore
    return Dictionary.unique;
  } // @ts-ignore


  Dictionary.unique = this;
  this.dicObj = {};
  this.dicMap = {};
  this.fetchingObj = {};
  this.fetchCount = 0;
  this.store = null;

  this.getStore = function () {
    if (!this.store && window._store) {
      this.store = window._store;
    }
  };

  this.setStore = function (store) {
    this.store = store;
  };

  this.put = function (codeType, data, labelName, valueName) {
    if (this.dicObj[codeType]) {
      throw new Error("codeType:".concat(codeType, " \u5DF2\u5B58\u5728\uFF0C\u5982\u679C\u8981\u8986\u76D6\u8BF7\u4F7F\u7528refresh\u65B9\u6CD5"));
    }

    this.createMap(codeType, data, labelName, valueName);
    this.dicObj[codeType] = data;
  };

  this.refresh = function (codeType, data, labelName, valueName) {
    this.dicObj[codeType] = data;
    this.createMap(codeType, data, labelName, valueName);
    this.update();
  }; // 试图更新


  this.update = function () {
    if (this.fetchCount === 0) {
      this.getStore(); // this.fetchCount === 0 && console.warn('dic update')

      this.store && this.store.dispatch({
        type: 'dictionary/saveDictionary'
      });
    }
  };

  this.clear = function () {
    this.fetchingObj = {};
    this.dicObj = {};
    this.fetchCount = 0;
  };

  this.get = function (_ref) {
    var _this = this;

    var url = _ref.url,
        options = _ref.options,
        codeType = _ref.codeType,
        getData = _ref.getData,
        labelName = _ref.labelName,
        valueName = _ref.valueName,
        loadSuccess = _ref.loadSuccess;

    if (this.fetchingObj[codeType]) {
      return [];
    }

    try {
      if (getData) {
        if (!codeType) {
          throw new Error('请加上codeType字段');
        } else {
          this.fetchCount += 1;
          this.fetchingObj[codeType] = true;
          return getData().then(function (res) {
            _this.fetchingObj[codeType] = false;
            var data;

            if (labelName || valueName) {
              data = res.map(function (item) {
                return {
                  key: item[valueName || 'key'],
                  label: item[labelName || 'label']
                };
              });
            }

            _this.dicObj[codeType] = data || res;

            _this.createMap(codeType, res, labelName, valueName);

            _this.fetchCount -= 1;
            loadSuccess && loadSuccess(_this.dicObj[codeType]);

            _this.update();
          });
        }
      }

      if (this.dicObj[codeType]) {
        return this.dicObj[codeType];
      }

      this.fetchCount += 1;
      this.fetchingObj[codeType] = true;
      var formData = new FormData();
      formData.append('codeType', codeType);
      (0, _request["default"])(url || '../system/getDataDictionary', _extends({
        method: 'post',
        credentials: 'include',
        body: formData
      }, options)).then(function (res) {
        if (Array.isArray(res)) {
          _this.dicObj[codeType] = res;

          _this.createMap(codeType, res, labelName, valueName);
        } else {
          _this.dicObj[codeType] = res.data;

          _this.createMap(codeType, res.data, labelName, valueName);
        }

        _this.fetchingObj[codeType] = false;
        _this.fetchCount -= 1;
        loadSuccess && loadSuccess(_this.dicObj[codeType]);

        _this.update();
      });
      return [];
    } catch (err) {
      this.fetchCount = 0; // this.update();
    }
  };

  this.getLabel = function (codeType, key) {
    if (this.dicMap[codeType]) {
      return this.dicMap[codeType][key];
    }

    this.get({
      codeType: codeType
    });
    return '';
  };

  this.getKey = function (codeType, label) {
    if (this.dicMap[codeType]) {
      return this.dicMap[codeType]["label_".concat(label)];
    }

    this.get({
      codeType: codeType
    });
    return '';
  };

  this.createMap = function (codeType, data) {
    var labelName = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'label';
    var valueName = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 'key';
    var map = {};
    data.map(function (item) {
      map[item[valueName]] = item[labelName];
      map["label_".concat(item[labelName])] = item[valueName];
      return null;
    });
    this.dicMap[codeType] = map;
  };
} // @ts-ignore


window.Dictionary = new Dictionary();
window.Dic = window.Dictionary;
var _default = Dictionary;
exports["default"] = _default;